@@ -30,14 +30,32 @@
 //! ```
 //!
 //! ## Increase NOFILE limit
-//! See the example [nofile](https://github.com/Nugine/rlimit/tree/v0.6.1/examples/nofile.rs).
+//! See the example [nofile](https://github.com/Nugine/rlimit/tree/v0.7.0/examples/nofile.rs).
 //!
-//! You can also use the tools in [`rlimit::utils`][`crate::utils`].
+//! You can also use the tool function showed below:
 //!
 //! ```no_run
-//! use rlimit::utils::increase_nofile_limit;
-//! increase_nofile_limit(10240).unwrap();
-//! increase_nofile_limit(u64::MAX).unwrap();
+//! rlimit::increase_nofile_limit(10240).unwrap();
+//! rlimit::increase_nofile_limit(u64::MAX).unwrap();
+//! ```
+//!
+//! ## Windows
+//!
+//! Windows does not have Unix-like resource limits.
+//! It only supports changing the number of simultaneously open files currently permitted at the stdio level.
+//!
+//! See the official documentation of
+//! [`_getmaxstdio`](https://docs.microsoft.com/en-us/cpp/c-runtime-library/reference/getmaxstdio?view=msvc-170)
+//! and
+//! [`_setmaxstdio`](https://docs.microsoft.com/en-us/cpp/c-runtime-library/reference/setmaxstdio?view=msvc-170).
+//!
+//! ```no_run
+//! # #[cfg(windows)]
+//! # {
+//! println!("{}", rlimit::getmaxstdio()); // 512
+//! rlimit::setmaxstdio(2048).unwrap();
+//! println!("{}", rlimit::getmaxstdio()); // 2048
+//! # }
 //! ```
 //!
 //! # Troubleshoot
@@ -48,10 +66,11 @@
 //! via sysctl (`kern.maxfilesperproc`). Failing to discover this secret stricter hard limit will
 //! cause the call to setrlimit to fail.
 //!
-//! [`rlimit::utils::increase_nofile_limit`][`crate::utils::increase_nofile_limit`]
+//! [`rlimit::increase_nofile_limit`][`crate::increase_nofile_limit`]
 //! respects `kern.maxfilesperproc`.
 //!
 
+#![cfg_attr(docsrs, feature(doc_cfg))]
 #![deny(
     missing_docs,
     missing_debug_implementations,
@@ -76,4 +95,15 @@ group! {
     pub use self::unix::*;
 }
 
-pub mod utils;
+#[cfg(any(doc, windows))]
+group! {
+    mod windows;
+
+    #[doc(inline)]
+    pub use self::windows::*;
+}
+
+mod tools;
+
+#[doc(inline)]
+pub use self::tools::*;
